@@ -58,11 +58,12 @@ class Editor (hildon.TextView):
     self.modify_font (pango.FontDescription (font_name+" "+str(font_size)))
     self.language = language
     self.searched_text = None
-
+    self.expose_event_cb = None
+    
     if prefs.prefs_dict['show_lines'] == True:
       self.set_border_window_size(gtk.TEXT_WINDOW_LEFT, 30)
       self.line_view = self.get_window(gtk.TEXT_WINDOW_LEFT)
-      self.connect("expose_event", self.line_numbers_expose)
+      self.expose_event_cb = self.connect("expose_event", self.line_numbers_expose)
   
 #  def on_key_press(self, widget, event, *args):
 #    #CTRL-S : save
