@@ -25,7 +25,7 @@ class Prefs():
       
   def default(self):
     self.prefs_dict['hildon_text_completion']=True
-    self.prefs_dict['default_language']='python'     ut
+    self.prefs_dict['default_language']='python'
     self.prefs_dict['font_name']='Monospace'     
     self.prefs_dict['font_size']='12'     
     self.prefs_dict['auto_rotate']=True     
