@@ -26,7 +26,7 @@ import sys
 
 class PyGTKEditor:
 
-  VERSION = '3.0.10'
+  VERSION = '3.0.11'
 
   def __init__(self):
     
@@ -67,17 +67,11 @@ class PyGTKEditor:
     if uri.startswith('file://'):
       self.create_window(uri[7:])
       
-  def onAbout(self, widget):                                                   
-    dialog = gtk.AboutDialog()                                                 
-    dialog.set_name("PyGTKEditor")                                             
-    dialog.set_logo_icon_name("pygtkeditor")                                   
-    dialog.set_comments('A source code editor for Maemo')                      
-    dialog.set_version(self.VERSION)                                                
-    dialog.set_copyright("By Benoit HERVIER (aka Khertan)")                    
-    dialog.set_website("http://khertan.net/")                                  
-    dialog.connect ("response", lambda d, r: d.destroy())                      
-    dialog.show()     
-
+  def onAbout(self, widget):
+    import about
+    d = about.Dialog('PyGTKEditor',self.VERSION,'A source code editor for Maemo','pygtkeditor','GPLv2','http://khertan.net/','http://bugs.maemo.org')
+    d.run()
+    d.destroy()
 
   def _manage_theme(self):
     icons = (( gtk.STOCK_ADD,   "general_add" ),
